@@ -1,7 +1,11 @@
+from pyhafas.profile.vsn.requests.journey import VSNJourneyRequest
 from pyhafas.profile import BaseProfile
 
 
-class VSNProfile(BaseProfile):
+class VSNProfile(VSNJourneyRequest, BaseProfile):
+    """
+    Profile for the HaFAS of "Verkehrsverbund Süd-Niedersachsen" (VSN) - local transportation provider
+    """
     baseUrl = "https://fahrplaner.vsninfo.de/hafas/mgate.exe"
     defaultUserAgent = "vsn/5.3.1 (iPad; iOS 13.3; Scale/2.00)"
 
@@ -27,7 +31,7 @@ class VSNProfile(BaseProfile):
         }
     }
 
-    available_products = {
+    availableProducts = {
         'long_distance_express': [1],  # ICE
         'long_distance': [2],  # IC/EC/CNL
         'regional_express': [4],  # RE/IR
@@ -40,7 +44,7 @@ class VSNProfile(BaseProfile):
         'anruf_sammel_taxi': [512]  # Group Taxi
     }
 
-    default_products = [
+    defaultProducts = [
         'long_distance_express',
         'long_distance',
         'regional_express',
